@@ -101,8 +101,8 @@ class RejawClient(object):
     def get_conversation_info(self, conversation_id):
         return self._get('conversation/get_info', {'api_key': self.api_key, 'cid': conversation_id}, False)
         
-    def shout(self, text):
-        return self._post('conversation/shout', {'text': text})
+    def shout(self, text, room=None):
+        return self._post('conversation/shout', {'text': text, 'room': room})
         
     def whisper(self, text, users):
         return self._post('conversation/whisper', {'text': text, 'users': users})
@@ -166,7 +166,29 @@ class RejawClient(object):
         self._session_check(parameters, True)
         self._clean_params(parameters)
         return self._do_api(Request("%s?%s" % (path, urlencode(parameters))))
-        
+    
+    # ============
+    # = Room API =
+    # ============
+    
+    def get_room_info(self, room):
+        self._get('room/get_info', {'room': room})
+    
+    def get_room_members(self, room):
+        self._get('room/get_members', {'room': room})
+    
+    def add_room_user(self, room, username):
+        self._post('room/add_user', {'room': room, 'username': username})
+    
+    def remove_room_user(self, room, username):
+        self._post('room/remove_user', {'room': room, 'username': username})
+    
+    def grant_room_owner(self, room, username):
+        self._post('room/grant_owner', {'room': room, 'username': username})
+    
+    def revoke_room_owner(self, room, username):
+        self._post('room/revoke_owner', {'room': room, 'username': username})
+    
     
     def _post(self, path, parameters, require_session=True):
         """calls self._do_api with the POST request"""
